#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 coinbase-pro
version:              0.9.3.2
visibility:           public
id:                   coinbase-pro-0.9.3.2-DqyqqFWXM4K7BqCwRlV2pG
key:                  coinbase-pro-0.9.3.2-DqyqqFWXM4K7BqCwRlV2pG
license:              MIT
copyright:            2022 Michael Dunn <michaelsdunn1@gmail.com>
maintainer:           Michael Dunn <michaelsdunn1@gmail.com>
author:               Michael Dunn <michaelsdunn1@gmail.com>
homepage:             https://github.com/mdunnio/coinbase-pro#readme
synopsis:             Client for Coinbase Pro
description:          Client for Coinbase Pro REST and Websocket APIs
category:             Web, Finance
abi:                  a59adfe2c3b5a21ee219ddcced435053
exposed:              True
exposed-modules:
    CoinbasePro.Authenticated CoinbasePro.Authenticated.API
    CoinbasePro.Authenticated.Accounts
    CoinbasePro.Authenticated.CoinbaseAccounts
    CoinbasePro.Authenticated.Conversion
    CoinbasePro.Authenticated.Deposit CoinbasePro.Authenticated.Fills
    CoinbasePro.Authenticated.Headers CoinbasePro.Authenticated.Limits
    CoinbasePro.Authenticated.Oracle CoinbasePro.Authenticated.Orders
    CoinbasePro.Authenticated.Payment CoinbasePro.Authenticated.Profile
    CoinbasePro.Authenticated.Report CoinbasePro.Authenticated.Request
    CoinbasePro.Authenticated.Transfer
    CoinbasePro.Authenticated.Withdrawal CoinbasePro.Environment
    CoinbasePro.Headers CoinbasePro.MarketData.AggregateOrderBook
    CoinbasePro.MarketData.FullOrderBook CoinbasePro.MarketData.Types
    CoinbasePro.Request CoinbasePro.Types CoinbasePro.Unauthenticated
    CoinbasePro.Unauthenticated.API CoinbasePro.WebSocketFeed
    CoinbasePro.WebSocketFeed.Channel
    CoinbasePro.WebSocketFeed.Channel.Full.Activate
    CoinbasePro.WebSocketFeed.Channel.Full.Change
    CoinbasePro.WebSocketFeed.Channel.Full.Done
    CoinbasePro.WebSocketFeed.Channel.Full.Match
    CoinbasePro.WebSocketFeed.Channel.Full.Open
    CoinbasePro.WebSocketFeed.Channel.Full.Received
    CoinbasePro.WebSocketFeed.Channel.Heartbeat
    CoinbasePro.WebSocketFeed.Channel.Level2
    CoinbasePro.WebSocketFeed.Channel.Status
    CoinbasePro.WebSocketFeed.Channel.Ticker
    CoinbasePro.WebSocketFeed.Request
    CoinbasePro.WebSocketFeed.Response

hidden-modules:       Paths_coinbase_pro
import-dirs:          /usr/lib/ghc-9.6.6/site-local/coinbase-pro-0.9.3.2
library-dirs:         /usr/lib/ghc-9.6.6/site-local/coinbase-pro-0.9.3.2
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/coinbase-pro-0.9.3.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-coinbase-pro
hs-libraries:         HScoinbase-pro-0.9.3.2-DqyqqFWXM4K7BqCwRlV2pG
depends:
    HsOpenSSL-0.11.7.9-LBtSxZW2rmK2S2GXK28cSX
    aeson-2.2.1.0-LCgCxr5fZ2fF779OJkJoWg
    aeson-casing-0.2.0.0-81P0EFLW5XNDRShMdzc3dy
    async-2.2.5-4DIIy34WjVcL8AkZ9wmUb5 base-4.18.2.1 binary-0.8.9.1
    bytestring-0.11.5.3 containers-0.6.7
    cryptonite-0.30-4cHU7zm53fU6KnRMTtlwQj exceptions-0.10.7
    http-api-data-0.6.1-DS8cYtn95v21Tc5ificfoq
    http-client-0.7.19-7Wwvx82yqlRGIUYbPQupWM
    http-client-tls-0.3.6.4-JiThctbTuGjJnqPKqN9uA0
    http-streams-0.8.9.9-4d4JRMHG8kcCxaVAM4tbac
    http-types-0.12.4-KZ6vNca015f4t5S0BZrDwk
    io-streams-1.5.2.2-5agzf72lT9P5pjpJkk7Mur
    memory-0.18.0-6zo36PbRecTK4fqbBnx0f5
    network-3.1.4.0-6AYqb02akSc9hPJrZzNJ51
    servant-0.20.3.0-B7blVKOHu4kC5C3BqHmrl6
    servant-client-0.20.3.0-GroGtw8BHEN5PCUyniWte9
    servant-client-core-0.20.3.0-4WBU9O7wVoPLDYgjHEodyF
    tasty-1.5.2-633hFGujPmiL9tN7qGhjKx
    tasty-hunit-0.10.2-FFDCOyyzTxsBfRTpU1RnxC text-2.0.2 time-1.12.2
    transformers-0.6.1.0 unagi-streams-0.2.7-1LlEE95rtp96DB4xCu0kFW
    unordered-containers-0.2.20.1-LFprVvrjTX4JVFniJRp7e6
    uuid-1.3.16-8PLS3U9MzfvCHukHLZ9xyd
    vector-0.13.2.0-KR0oqssWe4cgn21CCdckk
    websockets-0.12.7.3-3gS58j3cqbU8gWinOvrTZH
    wuss-2.0.1.6-263xQ68bp8Q173vkVSGV3O

haddock-interfaces:
    /usr/share/doc/haskell-coinbase-pro/html/coinbase-pro.haddock

haddock-html:         /usr/share/doc/haskell-coinbase-pro/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

